Example using ensemble class methods — Version 0.11.0.dev0

# Example using ensemble class methods

Under-sampling methods implies that samples of the majority class are lost during the balancing procedure. Ensemble methods offer an alternative to use most of the samples. In fact, an ensemble of balanced sets is created and used to later train any classifier.

Bagging classifiers using sampler

Bagging classifiers using sampler

Compare ensemble classifiers using resampling

Compare ensemble classifiers using resampling

previous

Create an imbalanced dataset

next

Bagging classifiers using sampler